@@ -13,12 +13,10 @@
 ##############################################################################
 """Tests for browser:page directive and friends
 """
-
 import sys
 import os
 import unittest
 from doctest import DocTestSuite
-from cStringIO import StringIO
 
 from zope import component
 from zope.interface import Interface, implementer, directlyProvides, providedBy
@@ -45,6 +43,11 @@ from zope.browsermenu.menu import getFirstMenuItem
 from zope.browsermenu.interfaces import IMenuItemType
 from zope.component.testfiles.views import IC, V1, VZMI, R1, IV
 
+try:
+    from cStringIO import StringIO
+except ImportError:
+    from io import StringIO
+
 tests_path = os.path.dirname(__file__)
 
 template = """<configure
@@ -137,7 +140,7 @@ class Test(cleanup.CleanUp, unittest.TestCase):
             )))
 
         v = component.queryMultiAdapter((ob, request), name='test')
-        self.assert_(issubclass(v.__class__, V1))
+        self.assertTrue(issubclass(v.__class__, V1))
 
 
     def testPageWithClassWithMenu(self):
@@ -166,7 +169,8 @@ class Test(cleanup.CleanUp, unittest.TestCase):
         self.assertEqual(menuItem["title"], "Test View")
         self.assertEqual(menuItem["action"], "@@test")
         v = component.queryMultiAdapter((ob, request), name='test')
-        self.assertEqual(v(), "<html><body><p>test</p></body></html>\n")
+        self.assertEqual(v().replace('\r\n', '\n'),
+                         "<html><body><p>test</p></body></html>\n")
 
 
     def testPageWithTemplateWithMenu(self):
@@ -194,7 +198,8 @@ class Test(cleanup.CleanUp, unittest.TestCase):
         self.assertEqual(menuItem["title"], "Test View")
         self.assertEqual(menuItem["action"], "@@test")
         v = component.queryMultiAdapter((ob, request), name='test')
-        self.assertEqual(v(), "<html><body><p>test</p></body></html>\n")
+        self.assertEqual(v().replace('\r\n', '\n'),
+                         "<html><body><p>test</p></body></html>\n")
 
 
     def testPageInPagesWithTemplateWithMenu(self):
@@ -224,7 +229,8 @@ class Test(cleanup.CleanUp, unittest.TestCase):
         self.assertEqual(menuItem["title"], "Test View")
         self.assertEqual(menuItem["action"], "@@test")
         v = component.queryMultiAdapter((ob, request), name='test')
-        self.assertEqual(v(), "<html><body><p>test</p></body></html>\n")
+        self.assertEqual(v().replace('\r\n', '\n'),
+                         "<html><body><p>test</p></body></html>\n")
 
 
     def testPageInPagesWithClassWithMenu(self):
@@ -255,7 +261,8 @@ class Test(cleanup.CleanUp, unittest.TestCase):
         self.assertEqual(menuItem["title"], "Test View")
         self.assertEqual(menuItem["action"], "@@test")
         v = component.queryMultiAdapter((ob, request), name='test')
-        self.assertEqual(v(), "<html><body><p>test</p></body></html>\n")
+        self.assertEqual(v().replace('\r\n', '\n'),
+                         "<html><body><p>test</p></body></html>\n")
 
     def testSkinPage(self):
         self.assertEqual(
@@ -281,10 +288,10 @@ class Test(cleanup.CleanUp, unittest.TestCase):
             )))
 
         v = component.queryMultiAdapter((ob, request), name='test')
-        self.assert_(issubclass(v.__class__, V1))
+        self.assertTrue(issubclass(v.__class__, V1))
         v = component.queryMultiAdapter(
             (ob, TestRequest(skin=ITestSkin)), name='test')
-        self.assert_(issubclass(v.__class__, VZMI))
+        self.assertTrue(issubclass(v.__class__, VZMI))
 
 
     def testInterfaceProtectedPage(self):
@@ -397,7 +404,7 @@ class Test(cleanup.CleanUp, unittest.TestCase):
 
         v = component.getMultiAdapter((ob, request), name='test')
         self.assertEqual(v.index(), v)
-        self.assert_(IBrowserPublisher.providedBy(v))
+        self.assertTrue(IBrowserPublisher.providedBy(v))
 
     def testIncompleteProtectedPageNoPermission(self):
         self.assertRaises(
@@ -441,7 +448,8 @@ class Test(cleanup.CleanUp, unittest.TestCase):
         v = component.getMultiAdapter((ob, request), name='action.html')
         self.assertEqual(v(), 'done')
         v = component.getMultiAdapter((ob, request), name='test.html')
-        self.assertEqual(str(v()), '<html><body><p>done</p></body></html>\n')
+        self.assertEqual(str(v()).replace('\r\n', '\n'),
+                         "<html><body><p>done</p></body></html>\n")
 
     def testNamedViewPageViewsCustomTraversr(self):
         self.assertEqual(
@@ -551,7 +559,8 @@ class Test(cleanup.CleanUp, unittest.TestCase):
         self.assertEqual(v(), 'done')
         v = view.publishTraverse(request, 'test.html')
         v = removeSecurityProxy(v)
-        self.assertEqual(str(v()), '<html><body><p>done</p></body></html>\n')
+        self.assertEqual(str(v()).replace('\r\n', '\n'),
+                         "<html><body><p>done</p></body></html>\n")
 
     def testNamedViewPageViewsWithDefault(self):
         self.assertEqual(
@@ -589,7 +598,8 @@ class Test(cleanup.CleanUp, unittest.TestCase):
         self.assertEqual(v(), 'done')
         v = view.publishTraverse(request, 'test.html')
         v = removeSecurityProxy(v)
-        self.assertEqual(str(v()), '<html><body><p>done</p></body></html>\n')
+        self.assertEqual(str(v()).replace('\r\n', '\n'),
+                         "<html><body><p>done</p></body></html>\n")
 
     def testTraversalOfPageForView(self):
         """Tests proper traversal of a page defined for a view."""
@@ -918,7 +928,7 @@ class Test(cleanup.CleanUp, unittest.TestCase):
             ))
 
         v = component.queryMultiAdapter((ob, request), IV, name='test')
-        self.assert_(isinstance(v, V1))
+        self.assertTrue(isinstance(v, V1))
 
     def testUnnamedViewThatProvidesAnInterface(self):
         request = TestRequest()
@@ -951,7 +961,7 @@ class Test(cleanup.CleanUp, unittest.TestCase):
 
         v = component.queryMultiAdapter((ob, request), IV)
 
-        self.assert_(isinstance(v, V1))
+        self.assertTrue(isinstance(v, V1))
 
 
 def test_suite():
